@@ -1,14 +1,14 @@
 #ifndef lint
-static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/debug.c,v 1.5 1999/02/25 01:05:05 unammx Exp $";
+static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/Attic/debug.c,v 1.5.8.1 2002/01/28 20:52:24 kmaraas Exp $";
 #endif
 /*****
 * debug.c : debug initialization routines.
 *
-* This file Version	$Revision: 1.5 $
+* This file Version	$Revision: 1.5.8.1 $
 *
 * Creation date:		Fri Oct 18 23:57:23 GMT+0100 1996
-* Last modification: 	$Date: 1999/02/25 01:05:05 $
-* By:					$Author: unammx $
+* Last modification: 	$Date: 2002/01/28 20:52:24 $
+* By:					$Author: kmaraas $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -35,6 +35,11 @@ static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/debug.c,v 1.5 199
 /*****
 * ChangeLog 
 * $Log: debug.c,v $
+* Revision 1.5.8.1  2002/01/28 20:52:24  kmaraas
+* 2002-01-28  Kjartan Maraas  <kmaraas@gnome.org>
+*
+* 	* debug.c: Don't assume getpid() returns an int.
+*
 * Revision 1.5  1999/02/25 01:05:05  unammx
 * Missing bit of the strtok patches from Ulrich
 *
@@ -340,7 +345,7 @@ __rsd_setDebugLevels(int *argc, char **argv)
 
 					chPtr++;	/* skip : */
 					if(!strcmp(chPtr, "pid"))	/* <pid>.out */
-						sprintf(tmp, "%i.out", (int)getpid());
+						sprintf(tmp, "%ld.out", (long)getpid());
 					else
 					{
 						strncpy(tmp, chPtr, 128);
@@ -353,7 +358,7 @@ __rsd_setDebugLevels(int *argc, char **argv)
 						fprintf(stderr, "__rsd_setDebugLevels: writing debug "
 							"output to %s\n", tmp);
 						fprintf(__rsd_debug_file, "XmHTML debug output file "
-							"for process %i\n", getpid());
+							"for process %ld\n", (long)getpid());
 						curr_time = time(NULL);
 						fprintf(__rsd_debug_file, "Created on %s\n\n",
 							ctime(&curr_time));
