@@ -207,7 +207,7 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
   close(parent_comm_pipes[0]);
 
   if(child_pid < 0)
-    g_message("gnome_execute_async_with_env_fds: returning %d", child_pid);
+    g_message("gnome_execute_async_with_env_fds: returning %ld", (long)child_pid);
 
   return child_pid;
 }
