@@ -106,7 +106,7 @@ static void
 write_history_entry(GnomeHistoryEntry ent, FILE *outfile)
 {
 	fprintf(outfile, "%s %s %s %s\n",
-		ent->filename, ent->filetype, ent->creator, ent->desc == NULL ? "" : ent->desc);
+		ent->filename, ent->filetype, ent->creator, ent->desc ? ent->desc : "");
 }
 
 static void
