@@ -145,6 +145,8 @@ gnomewm_check_wm(Display *dpy)
 		  XFree(prop3);
 		  return TRUE;
 		}
+		XFree(prop3);
+		return FALSE;
 	    }
 	    XFree(prop3);
 	  }
@@ -844,47 +846,89 @@ escape_url (char *url)
 int
 main (int argc, char **argv)
 {
-  Display *dpy;
+  Display *dpy = NULL;
   char *def;
+  char *margv[5];
+  char *buf;
+  char *escaped_url = NULL;
 
   /* Parse arguments ... */
   gnomelib_init("gnome-moz-remote", VERSION);
   gnomelib_register_popt_table(options, "gnome-moz-remote options");
   poptFreeContext(gnomelib_parse_args(argc, argv, 0));
-
-  dpy = XOpenDisplay (dpy_string);
-  if (! dpy)
-    return (-1);
-
-  if (sync_p)
-    XSynchronize (dpy, True);
+  
+  if (url_string) {
+    
+    escaped_url = escape_url (url_string);
+  }
+  
+  /* Does the requested web browser support the netscape remote protocol? */
+  if (gnome_config_get_bool ("gnome-moz-remote/Mozilla/NREMOTE=true")) {
+    
+    dpy = XOpenDisplay (dpy_string);
+    if (! dpy)
+      return (-1);
+    
+    if (sync_p)
+      XSynchronize (dpy, True);
+    
+    if (url_string) {
+      if (!g_strncasecmp(escaped_url, "file:", 5))
+	isLocal = True;;
+      buf = g_strdup_printf("openURL(%s%s)",
+			    escaped_url, new_window ? ",new-window" : "");
+      if (!mozilla_remote_cmd(dpy, (Window) remote_window, buf,
+			      raise_p, isLocal))
+	exit(0);
+    }
+  }
 
   if (url_string) {
-    char *argv[3];
-    char *buf, *escaped_url;
-
-    escaped_url = escape_url (url_string);
-
-    if (!g_strncasecmp(escaped_url, "file:", 5))
-      isLocal = True;;
-    buf = g_strdup_printf("openURL(%s%s)",
-			  escaped_url, new_window ? ",new-window" : "");
-    if (!mozilla_remote_cmd(dpy, (Window) remote_window, buf,
-			    raise_p, isLocal))
-      exit(0);
-
-    if (gnome_is_program_in_path ("mozilla"))
-	    def = "/gnome-moz-remote/Mozilla/filename=mozilla";
-    else
-	    def = "/gnome-moz-remote/Mozilla/filename=netscape";
     
-    argv[0] = gnome_config_get_string(def);
-    argv[1] = escaped_url;
-    argv[2] = NULL;
-    return (gnome_execute_async(NULL, 2, argv) >= 0);
+    if (gnome_is_program_in_path ("mozilla"))
+      def = "/gnome-moz-remote/Mozilla/filename=mozilla";
+    else
+      def = "/gnome-moz-remote/Mozilla/filename=netscape";
+    
+    if (gnome_config_get_bool ("/gnome-moz-remote/Mozilla/NEEDS_TERM=false")) {
+      char **term_argv;
+      int term_argc;
+
+      term_argv = g_new0 (char *, 3);
+
+      gnome_config_get_vector ("/Gnome/Applications/Terminal",
+			       &term_argc, &term_argv);
+      if (term_argv == NULL) {
+	char *check;
+	check = gnome_is_program_in_path("gnome-terminal");
+	term_argc = 2;
+	if (!check) {
+	  term_argv[0] = "xterm";
+	  term_argv[1] = "-e";
+	} else {
+	  term_argv[0] = "gnome-terminal";
+	  term_argv[1] = "-x";
+	}
+      }
+
+      margv[0] = term_argv[0];
+      margv[1] = term_argv[1];
+      margv[2] = gnome_config_get_string(def);
+      margv[3] = escaped_url;
+      margv[4] = NULL;
+      
+      return (gnome_execute_async(NULL, 4, margv) >= 0);
+      
+
+    } else {      
+      margv[0] = gnome_config_get_string(def);
+      margv[1] = escaped_url;
+      margv[2] = NULL;
+      return (gnome_execute_async(NULL, 2, margv) == -1);
+    }
   } else
     if (remote_commands)
-        return (mozilla_remote_commands (dpy, (Window) remote_window,
-					 remote_commands, isLocal));
+      return (mozilla_remote_commands (dpy, (Window) remote_window,
+				       remote_commands, isLocal));
   return 0;
 }
