@@ -18,10 +18,6 @@
 #include "gnome-defs.h"
 #include "libgnomeP.h"
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
 static GArray *opt_tables = NULL;
 
 /**
@@ -62,6 +58,8 @@ gnomelib_register_popt_table (const struct poptOption *options,
  *
  * Parses the arguments in argv according to all of the registered
  * tables.
+ *
+ * Returns a poptContext to the remaining arguments.
  */
 poptContext
 gnomelib_parse_args (int argc, char *argv[], int popt_flags)
