@@ -25,13 +25,6 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-/* FONTS */
-#define HELVETICA_20_BFONT "-adobe-helvetica-bold-r-normal-*-20-*-*-*-*-*-*-*"
-#define HELVETICA_14_BFONT "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-*-*"
-#define HELVETICA_12_BFONT "-adobe-helvetica-bold-r-normal-*-12-*-*-*-*-*-*-*"
-#define HELVETICA_12_FONT  "-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-*-*"
-#define HELVETICA_10_FONT  "-adobe-helvetica-medium-r-normal-*-10-*-*-*-*-*-*-*"
-
 #define GNOME_ABOUT_DEFAULT_WIDTH               100
 #define GNOME_ABOUT_MAX_WIDTH                   600
 #define BASE_LINE_SKIP                          0
@@ -413,8 +406,8 @@ gnome_fill_info (GtkWidget *widget,
 	/* Create fonts */
 	/* FIXME: dirty hack, but it solves i18n problem without rewriting the
 	   drawing code..  */
-	style = gtk_style_ref (widget->style);
 	gtk_widget_ensure_style(widget);
+	style = gtk_style_ref (widget->style);
  
 	gtk_widget_set_name (widget, "Title");
 	gai->font_title = gdk_font_ref (widget->style->font);
