@@ -91,6 +91,23 @@ static const char strings [] = {
 	N_("_Game"), 
 	N_("_Help"), 
 	N_("_Windows/")
+	
+	N_("File"),
+	N_("File/"),
+	N_("Edit"),
+	N_("Edit/"),
+	N_("View"),
+	N_("View/"),
+	N_("Settings"),
+	N_("Settings/"),
+        N_("New"),
+	N_("New/"),
+	N_("Files"),
+	N_("Files/"),
+	N_("Windows"),
+	N_("Game"), 
+	N_("Help"), 
+	N_("Windows/")
 };
 
 #endif
@@ -869,7 +886,6 @@ create_menu_item (GtkMenuShell       *menu_shell,
 			 */
 
 		        if ((uiinfo->pixmap_type != GNOME_APP_PIXMAP_NONE) &&
-			    gnome_config_get_bool("/Gnome/Icons/MenusUseIcons=true") && 
 			    gnome_preferences_get_menus_have_icons()) {
 			        uiinfo->widget = gtk_pixmap_menu_item_new ();
 				pixmap = create_pixmap (uiinfo->widget, uiinfo->pixmap_type, 
