@@ -40,8 +40,6 @@ static void gnome_less_init       (GnomeLess      *messagebox);
 
 static void gnome_less_destroy (GtkObject *gl);
 
-static gint text_clicked_cb(GtkText * text, GdkEventButton * e, 
-			    GnomeLess * gl);
 static gboolean gnome_less_button_press_event (GtkText *text, GdkEventButton *button,
 					       gpointer data);
 					       
