@@ -20,7 +20,7 @@ typedef GnomeMDIChild *(*GnomeMDIChildCreator) (const gchar *);
 /* gnome_mdi_restore_state(): call this with the GnomeMDI object, the
  * config section name and the function used to recreate the GnomeMDIChildren
  * from their config strings. */
-gboolean	gnome_mdi_restore_state	(GnomeMDI *mdi, const char *section,
+gboolean	gnome_mdi_restore_state	(GnomeMDI *mdi, const gchar *section,
 					 GnomeMDIChildCreator child_create_func);
 
 /* gnome_mdi_save_state (): call this with the GnomeMDI object as the
