@@ -26,7 +26,7 @@ int main(int argc, char *argv[])
   poptContext ctx;
   const char **args;
   char *urlstr;
-  char *app_version = NULL;
+  const char *app_version = NULL;
   int res;
   gchar *appname;
   gchar *bug_buddy_path = NULL;
@@ -59,12 +59,12 @@ int main(int argc, char *argv[])
     {
       if (strcmp(g_filename_pointer (args[0]), "gnome-session") == 0)
         {
-          msg = g_strdup_printf(_("The GNOME Session Manager (process %d) has crashed\n"
+          msg = g_strdup_printf(_("The GNOME Session Manager (process %ld) has crashed\n"
                                   "due to a fatal error (%s).\n"
                                   "When you close this dialog, all applications will close "
                                   "and your session will exit.\nPlease save all your files "
                                   "before closing this dialog."),
-                                getppid(), g_strsignal(atoi(args[1])));
+                                (long)getppid(), g_strsignal(atoi(args[1])));
           bb_sm_disable = 1;
         }
       else
@@ -128,9 +128,9 @@ int main(int argc, char *argv[])
       int retval;
 
       g_assert(bug_buddy_path);
-      exec_str = g_strdup_printf("%s --appname=\"%s\" --pid=%d "
+      exec_str = g_strdup_printf("%s --appname=\"%s\" --pid=%ld "
                                  "--package-ver=\"%s\" %s", 
-                                 bug_buddy_path, appname, getppid(), 
+                                 bug_buddy_path, appname, (long)getppid(), 
                                  app_version, bb_sm_disable 
                                  ? "--sm-disable" : "");
 
@@ -147,9 +147,9 @@ int main(int argc, char *argv[])
       int retval;
 
       g_assert (debugger_path);
-      exec_str = g_strdup_printf("%s --appname=\"%s\" --pid=%d "
+      exec_str = g_strdup_printf("%s --appname=\"%s\" --pid=%ld "
                                  "--package-ver=\"%s\" %s", 
-                                 debugger_path, appname, getppid(), 
+                                 debugger_path, appname, (long)getppid(), 
                                  app_version, bb_sm_disable 
                                  ? "--sm-disable" : "");
 
