@@ -18,7 +18,7 @@ main(int argc, char* argv[])
 {
   CORBA_Environment  ev;
   poptContext ctx;
-  char **args;
+  const char **args;
 
   CORBA_exception_init(&ev);
 
