@@ -121,7 +121,7 @@ _gnorba_get_cookie_reliably (const char *setme)
 	struct passwd *pwent;
 	char buf[64];
 	char *random_string = NULL;
-	char *name;
+	char *name = NULL;
 	int fd = -1;
 	
 	pwent = getpwuid(getuid());
