@@ -11,7 +11,10 @@
 
 #include <gnomesupport.h>
 
-#include <gnome-argp.h>
+/* Some systems, like Red Hat 4.0, define these but don't declare
+   them.  Hopefully it is safe to always declare them here.  */
+extern char *program_invocation_short_name;
+extern char *program_invocation_name;
 
 /* Override some of config.h.
    Gnomesupport provides the replacements for these, so you actually
@@ -25,4 +28,8 @@
 # define HAVE_PROGRAM_INVOCATION_NAME 1
 #endif
 
+#ifndef HAVE_PROGRAM_INVOCATION_SHORT_NAME
+# define HAVE_PROGRAM_INVOCATION_SHORT_NAME 1
+#endif
+
 #endif /* GNOMESUPPORT_FAKE_H_ */
