@@ -392,7 +392,7 @@ create_canvas_arrowhead (void)
 	GnomeCanvasPoints *points;
 
 	vbox = gtk_vbox_new (FALSE, 4);
-	gtk_container_border_width (GTK_CONTAINER (vbox), 4);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
 	gtk_widget_show (vbox);
 
 	w = gtk_label_new ("This demo allows you to edit arrowhead shapes.  Drag the little boxes\n"
@@ -411,7 +411,7 @@ create_canvas_arrowhead (void)
 	gtk_widget_show (frame);
 
 	canvas = gnome_canvas_new ();
-	gnome_canvas_set_size (GNOME_CANVAS (canvas), 500, 350);
+	gtk_widget_set_usize (canvas, 500, 350);
 	gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas), 0, 0, 500, 350);
 	gtk_container_add (GTK_CONTAINER (frame), canvas);
 	gtk_widget_show (canvas);
