@@ -907,12 +907,14 @@ create_icon_list(void)
 	app = create_newwin(TRUE,"testGNOME","Icon List");
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
 	gnome_app_set_contents (GNOME_APP (app), sw);
 	gtk_widget_set_usize (sw, 430, 300);
 	gtk_widget_show (sw);
 
-	iconlist = gnome_icon_list_new (80, NULL, TRUE);
+	iconlist = gnome_icon_list_new_flags (80, NULL, GNOME_ICON_LIST_IS_EDITABLE);
 	gtk_container_add (GTK_CONTAINER (sw), iconlist);
 	gtk_signal_connect (GTK_OBJECT (iconlist), "select_icon",
 			    GTK_SIGNAL_FUNC (select_icon),
@@ -1814,13 +1816,13 @@ static void
 create_dentry_edit(void)
 {
 	GtkWidget *app;
-	GtkWidget *edit;
+	GtkObject *edit;
 	GtkWidget *nbook;
 
 	nbook = gtk_notebook_new();
 
 	app = create_newwin(TRUE,"testGNOME","DEntry Entry");
-	edit = GTK_WIDGET (gnome_dentry_edit_new_notebook(GTK_NOTEBOOK(nbook)));
+	edit = gnome_dentry_edit_new_notebook(GTK_NOTEBOOK(nbook));
 	gnome_app_set_contents(GNOME_APP(app),nbook);
 	gtk_widget_show_all(app);
 }
@@ -1910,7 +1912,7 @@ main (int argc, char *argv[])
 		  { "dentry edit", create_dentry_edit },
 		  { "href", create_href },
 		  { "(Reload preferences)", gnome_preferences_load },
-/*	{ "prop box", create_property_box }, */
+		  { "prop box", create_property_box },
 	  };
 	int nbuttons = sizeof (buttons) / sizeof (buttons[0]);
 	GtkWidget *app;
