@@ -6,7 +6,7 @@
 GtkWidget *create_newwin(gboolean normal, gchar *appname, gchar *title);
 
 void create_canvas (void);
-GtkWidget *create_canvas_primitives (void);
+GtkWidget *create_canvas_primitives (int aa);
 GtkWidget *create_canvas_arrowhead (void);
 GtkWidget *create_canvas_fifteen (void);
 GtkWidget *create_canvas_features (void);
