@@ -848,7 +848,7 @@ static int vt_in_wordclass(struct _vtx *vx, uint32 c)
   if (c>=256)
     return 1;
   ch = c&0xff;
-  return (vx->wordclass[ch>>3]&(1<<(ch&7)))!=0;
+  return vx->wordclass[ch>>3]&(1<<(ch&7))!=0;
 }
 
 /*
